=====================
|hpv_l| documentation
=====================

|hpv_s| is a stochastic agent-based simulator, written in Python, for exploring and analyzing human papillomavirus (HPV) transmission. 


Full contents
=============

.. toctree::
   :maxdepth: 4

   overview
   tutorials
   whats-new
   modules